pub fn set_in(fm: &mut Frontmatter, field: &str, refs: &[(String, String)])Expand description
Replace an arbitrary relation map, sorted by item number. An empty list removes the field entirely (keeping frontmatter minimal).
pub fn set_in(fm: &mut Frontmatter, field: &str, refs: &[(String, String)])Replace an arbitrary relation map, sorted by item number. An empty list removes the field entirely (keeping frontmatter minimal).