opys close — finish a document of a type that has a terminal status,
deleting its file and striking every reference to it into a tombstone.
opys close — finish a document of a type that has a terminal status,
deleting its file and striking every reference to it into a tombstone.